@@ -28,15 +28,12 @@
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KNewFileMenu>
-#include <KPluginMetaData>
 #include <KStandardAction>
-#include <KToolBar>
+#include <kio_version.h>
 
 #include <QApplication>
 #include <QClipboard>
 #include <QKeyEvent>
-#include <QMenuBar>
-#include <QMimeDatabase>
 
 DolphinContextMenu::DolphinContextMenu(DolphinMainWindow* parent,
                                        const KFileItem& fileInfo,
@@ -175,7 +172,11 @@ void DolphinContextMenu::addDirectoryItemContextMenu()
     // set up 'Create New' menu
     DolphinNewFileMenu* newFileMenu = new DolphinNewFileMenu(m_mainWindow->actionCollection(), m_mainWindow);
     newFileMenu->checkUpToDate();
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 97, 0)
+    newFileMenu->setWorkingDirectory(m_fileInfo.url());
+#else
     newFileMenu->setPopupFiles(QList<QUrl>() << m_fileInfo.url());
+#endif
     newFileMenu->setEnabled(selectedItemsProps.supportsWriting());
     connect(newFileMenu, &DolphinNewFileMenu::fileCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
     connect(newFileMenu, &DolphinNewFileMenu::directoryCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
@@ -280,7 +281,11 @@ void DolphinContextMenu::addViewportContextMenu()
     // Set up and insert 'Create New' menu
     KNewFileMenu* newFileMenu = m_mainWindow->newFileMenu();
     newFileMenu->checkUpToDate();
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 97, 0)
+    newFileMenu->setWorkingDirectory(m_baseUrl);
+#else
     newFileMenu->setPopupFiles(QList<QUrl>() << m_baseUrl);
+#endif
     addMenu(newFileMenu->menu());
 
     // Show "open with" menu items even if the dir is empty, because there are legitimate
