@@ -9,12 +9,10 @@
 
 #include "dolphin_generalsettings.h"
 #include "dolphinviewcontainer.h"
-#include "global.h"
 
-#include <QVariantAnimation>
 #include <QGridLayout>
-#include <QWidgetAction>
 #include <QStyle>
+#include <QVariantAnimation>
 
 DolphinTabPage::DolphinTabPage(const QUrl &primaryUrl, const QUrl &secondaryUrl, QWidget* parent) :
     QWidget(parent),
@@ -152,6 +150,8 @@ void DolphinTabPage::setSplitViewEnabled(bool enabled, Animated animated, const
                 view->setDisabled(true);
                 startExpandViewAnimation(m_primaryViewContainer);
             }
+
+            m_primaryViewContainer->slotSplitTabDisabled();
         }
     }
 }
