@@ -8,6 +8,8 @@
 #ifndef DOLPHIN_TAB_PAGE_H
 #define DOLPHIN_TAB_PAGE_H
 
+#include "global.h"
+
 #include <QPointer>
 #include <QUrl>
 #include <QWidget>
@@ -19,11 +21,6 @@ class QVariantAnimation;
 class KFileItemList;
 class DolphinTabPageSplitter;
 
-enum Animated {
-    WithAnimation,
-    WithoutAnimation
-};
-
 class DolphinTabPage : public QWidget
 {
     Q_OBJECT
