@@ -18,7 +18,6 @@
 #include <KWindowSystem>
 
 #include <QApplication>
-#include <QIcon>
 
 QList<QUrl> Dolphin::validateUris(const QStringList& uriList)
 {
@@ -93,7 +92,7 @@ bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFi
         do {
             auto &interface = dolphinInterfaces[i];
 
-            auto isUrlOpenReply = openFiles ? interface.first->isUrlOrParentOpen(urlString) : interface.first->isUrlOpen(urlString);
+            auto isUrlOpenReply = openFiles ? interface.first->isItemVisibleInAnyView(urlString) : interface.first->isUrlOpen(urlString);
             isUrlOpenReply.waitForFinished();
             if (!isUrlOpenReply.isError() && isUrlOpenReply.value()) {
                 interface.second.append(urlString);
