@@ -131,7 +131,7 @@ public:
      * Per default all plugins enabled in the KConfigGroup "PreviewSettings"
      * are used.
      *
-     * For a list of available plugins, call KServiceTypeTrader::self()->query("ThumbCreator").
+     * For a list of available plugins, call KIO::PreviewJob::availableThumbnailerPlugins().
      *
      * @see enabledPlugins
      */
@@ -177,7 +177,7 @@ public:
 private Q_SLOTS:
     void slotItemsInserted(const KItemRangeList& itemRanges);
     void slotItemsRemoved(const KItemRangeList& itemRanges);
-    void slotItemsMoved(const KItemRange& itemRange, const QList<int> &movedToIndexes);
+    void slotItemsMoved(KItemRange itemRange, const QList<int> &movedToIndexes);
     void slotItemsChanged(const KItemRangeList& itemRanges,
                           const QSet<QByteArray>& roles);
     void slotSortRoleChanged(const QByteArray& current,
