@@ -21,7 +21,6 @@
 #include <QGraphicsScene>
 #include <QGraphicsSceneResizeEvent>
 #include <QGraphicsView>
-#include <QGuiApplication>
 #include <QPixmapCache>
 #include <QStyleOption>
 
@@ -242,6 +241,7 @@ KStandardItemListWidget::KStandardItemListWidget(KItemListWidgetInformant* infor
     m_customizedFont(),
     m_customizedFontMetrics(m_customizedFont),
     m_isExpandable(false),
+    m_highlightEntireRow(false),
     m_supportsItemExpanding(false),
     m_dirtyLayout(true),
     m_dirtyContent(true),
@@ -1456,7 +1456,7 @@ void KStandardItemListWidget::updateAdditionalInfoTextColor()
     QColor c1;
     if (m_customTextColor.isValid()) {
         c1 = m_customTextColor;
-    } else if (isSelected()) {
+    } else if (isSelected() && (m_layout != DetailsLayout || m_highlightEntireRow)) {
         // The detail text colour needs to match the main text (HighlightedText) for the same level
         // of readability. We short circuit early here to avoid interpolating with another colour.
         m_additionalInfoTextColor = styleOption().palette.color(QPalette::HighlightedText);
