@@ -23,6 +23,7 @@
 #include <KLocalizedString>
 #include <KConfigGui>
 #include <KIO/PreviewJob>
+#include <KWindowSystem>
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
@@ -31,8 +32,6 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDBusConnection>
-#include <QDBusInterface>
-#include <QDBusAbstractInterface>
 #include <QDBusConnectionInterface>
 #include <QSessionManager>
 
@@ -88,10 +87,16 @@ int main(int argc, char **argv)
     KAboutData aboutData(QStringLiteral("dolphin"), i18n("Dolphin"), QStringLiteral(DOLPHIN_VERSION_STRING),
                          i18nc("@title", "File Manager"),
                          KAboutLicense::GPL,
-                         i18nc("@info:credit", "(C) 2006-2018 Peter Penz, Frank Reininghaus, Emmanuel Pescosta and Elvis Angelaccio"));
+                         i18nc("@info:credit", "(C) 2006-2022 The Dolphin Developers"));
     aboutData.setHomepage(QStringLiteral("https://kde.org/applications/system/org.kde.dolphin"));
+    aboutData.addAuthor(i18nc("@info:credit", "Felix Ernst"),
+                        i18nc("@info:credit", "Maintainer (since 2021) and developer"),
+                        QStringLiteral("felixernst@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Méven Car"),
+                        i18nc("@info:credit", "Maintainer (since 2021) and developer (since 2019)"),
+                        QStringLiteral("meven@kde.org"));
     aboutData.addAuthor(i18nc("@info:credit", "Elvis Angelaccio"),
-                        i18nc("@info:credit", "Maintainer (since 2018) and developer"),
+                        i18nc("@info:credit", "Maintainer (2018-2021) and developer"),
                         QStringLiteral("elvis.angelaccio@kde.org"));
     aboutData.addAuthor(i18nc("@info:credit", "Emmanuel Pescosta"),
                         i18nc("@info:credit", "Maintainer (2014-2018) and developer"),
@@ -171,7 +176,14 @@ int main(int argc, char **argv)
     }
 
     if (!parser.isSet(QStringLiteral("new-window"))) {
-        if (Dolphin::attachToExistingInstance(urls, openFiles, splitView)) {
+
+        QString token;
+        if (KWindowSystem::isPlatformWayland()) {
+            token = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
+            qunsetenv("XDG_ACTIVATION_TOKEN");
+        }
+
+        if (Dolphin::attachToExistingInstance(urls, openFiles, splitView, QString(), token)) {
             // Successfully attached to existing instance of Dolphin
             return 0;
         }
