@@ -29,7 +29,6 @@
 #include <QMenu>
 #include <QMimeData>
 #include <QShowEvent>
-#include <QTimer>
 
 #include <Solid/StorageAccess>
 
@@ -173,7 +172,11 @@ void PlacesPanel::slotUrlsDropped(const QUrl& dest, QDropEvent* event, QWidget*
 {
     KIO::DropJob *job = DragAndDropHelper::dropUrls(dest, event, parent);
     if (job) {
-        connect(job, &KIO::DropJob::result, this, [this](KJob *job) { if (job->error()) Q_EMIT errorMessage(job->errorString()); });
+        connect(job, &KIO::DropJob::result, this, [this](KJob *job) {
+            if (job->error() && job->error() != KIO::ERR_USER_CANCELED) {
+                Q_EMIT errorMessage(job->errorString());
+            }
+        });
     }
 }
 
@@ -229,7 +232,9 @@ void PlacesPanel::slotTearDownRequestedExternally(const QString &udi)
 void PlacesPanel::slotTearDownDone(Solid::ErrorType error, const QVariant& errorData)
 {
     if (error && errorData.isValid()) {
-        if (error == Solid::ErrorType::DeviceBusy) {
+        if (error == Solid::ErrorType::UserCanceled) {
+            // No need to tell the user what they just did.
+        } else if (error == Solid::ErrorType::DeviceBusy) {
             KListOpenFilesJob* listOpenFilesJob = new KListOpenFilesJob(m_deviceToTearDown->filePath());
             connect(listOpenFilesJob, &KIO::Job::result, this, [this, listOpenFilesJob](KJob*) {
                 const KProcessList::KProcessInfoList blockingProcesses = listOpenFilesJob->processInfoList();
