@@ -14,8 +14,8 @@
 #include "startup/startupsettingspage.h"
 #include "trash/trashsettingspage.h"
 #include "viewmodes/viewsettingspage.h"
-#include "config-kuserfeedback.h"
-#ifdef HAVE_KUSERFEEDBACK
+#include "config-dolphin.h"
+#if HAVE_KUSERFEEDBACK
 #include "userfeedback/dolphinfeedbackprovider.h"
 #include "userfeedback/userfeedbacksettingspage.h"
 #endif
@@ -25,6 +25,8 @@
 #include <KWindowConfig>
 #include <KMessageBox>
 
+#include <kwidgetsaddons_version.h>
+
 #include <QCloseEvent>
 #include <QPushButton>
 
@@ -86,7 +88,7 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
         QStringLiteral("open_in_new_window"),
         QStringLiteral("copy_location"),
         QStringLiteral("duplicate"),
-        QStringLiteral("open_terminal"),
+        QStringLiteral("open_terminal_here")
     });
     KPageWidgetItem* contextMenuSettingsFrame = addPage(contextMenuSettingsPage,
                                                         i18nc("@title:group", "Context Menu"));
@@ -105,7 +107,7 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
         connect(trashSettingsPage, &TrashSettingsPage::changed, this, &DolphinSettingsDialog::enableApply);
     }
 
-#ifdef HAVE_KUSERFEEDBACK
+#if HAVE_KUSERFEEDBACK
     // User Feedback
     UserFeedbackSettingsPage* feedbackSettingsPage = nullptr;
     if (DolphinFeedbackProvider::instance()->isEnabled()) {
@@ -124,7 +126,7 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
     if (trashSettingsPage) {
         m_pages.append(trashSettingsPage);
     }
-#ifdef HAVE_KUSERFEEDBACK
+#if HAVE_KUSERFEEDBACK
     if (feedbackSettingsPage) {
         m_pages.append(feedbackSettingsPage);
     }
@@ -179,17 +181,29 @@ void DolphinSettingsDialog::closeEvent(QCloseEvent* event)
         return;
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const auto response = KMessageBox::warningTwoActionsCancel(this,
+#else
     const auto response = KMessageBox::warningYesNoCancel(this,
+#endif
                                         i18n("You have unsaved changes. Do you want to apply the changes or discard them?"),
                                         i18n("Warning"),
                                         KStandardGuiItem::save(),
                                         KStandardGuiItem::discard(),
                                         KStandardGuiItem::cancel());
     switch (response) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        case KMessageBox::PrimaryAction:
+#else
         case KMessageBox::Yes:
+#endif
             applySettings();
             Q_FALLTHROUGH();
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        case KMessageBox::SecondaryAction:
+#else
         case KMessageBox::No:
+#endif
             event->accept();
             break;
         case KMessageBox::Cancel:
