@@ -6,7 +6,7 @@
 #ifndef CONFIRMATIONSSETTINGSPAGE_H
 #define CONFIRMATIONSSETTINGSPAGE_H
 
-#include "config-terminal.h"
+#include "config-dolphin.h"
 #include "settings/settingspagebase.h"
 
 class QCheckBox;
@@ -37,7 +37,7 @@ private:
     QCheckBox* m_confirmEmptyTrash;
     QCheckBox* m_confirmDelete;
 
-#ifdef HAVE_TERMINAL
+#if HAVE_TERMINAL
     QCheckBox* m_confirmClosingTerminalRunningProgram;
 #endif
 
