@@ -14,12 +14,10 @@
 #include <KIO/PreviewJob>
 #include <KLocalizedString>
 #include <KPluginMetaData>
-#include <KServiceTypeTrader>
 
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QListView>
-#include <QPainter>
 #include <QScroller>
 #include <QShowEvent>
 #include <QSortFilterProxyModel>
