@@ -27,7 +27,7 @@ DolphinFontRequester::DolphinFontRequester(QWidget* parent) :
     m_modeCombo = new QComboBox(this);
     m_modeCombo->addItem(i18nc("@item:inlistbox Font", "System Font"));
     m_modeCombo->addItem(i18nc("@item:inlistbox Font", "Custom Font"));
-    connect(m_modeCombo, QOverload<int>::of(&QComboBox::activated),
+    connect(m_modeCombo, &QComboBox::activated,
             this, &DolphinFontRequester::changeMode);
 
     m_chooseFontButton = new QPushButton(i18nc("@action:button Choose font", "Choose..."), this);
