@@ -56,6 +56,8 @@ private:
     DolphinFontRequester* m_fontRequester;
     QComboBox* m_widthBox;
     QComboBox* m_maxLinesBox;
+    QRadioButton* m_entireRow;
+    QRadioButton* m_iconAndNameOnly;
     QCheckBox* m_expandableFolders;
     QRadioButton* m_numberOfItems;
     QRadioButton* m_sizeOfContents;
