@@ -6,9 +6,10 @@
 
 #include "kitemviews/kfileitemlistview.h"
 #include "kitemviews/kfileitemmodel.h"
-#include "kitemviews/private/kfileitemmodeldirlister.h"
 #include "testdir.h"
 
+#include <KDirLister>
+
 #include <QGraphicsView>
 #include <QTest>
 #include <QSignalSpy>
