@@ -10,6 +10,7 @@
 
 #include <QTest>
 #include <QSignalSpy>
+#include <QStandardPaths>
 
 class DummyModel : public KItemModelBase
 {
@@ -51,7 +52,8 @@ class KItemListSelectionManagerTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
+    void initTestCase();
     void init();
     void cleanup();
 
@@ -76,6 +78,11 @@ private:
     DummyModel* m_model;
 };
 
+void KItemListSelectionManagerTest::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+}
+
 void KItemListSelectionManagerTest::init()
 {
     m_model = new DummyModel();
