@@ -14,7 +14,8 @@ class ViewPropertiesTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
+    void initTestCase();
     void init();
     void cleanup();
 
@@ -26,6 +27,11 @@ private:
     TestDir* m_testDir;
 };
 
+void ViewPropertiesTest::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+}
+
 void ViewPropertiesTest::init()
 {
     m_globalViewProps = GeneralSettings::self()->globalViewProps();
