@@ -23,6 +23,8 @@
 #include <QUrl>
 #include <QWidget>
 
+#include <memory>
+
 typedef KIO::FileUndoManager::CommandType CommandType;
 class QVBoxLayout;
 class DolphinItemListView;
@@ -36,6 +38,7 @@ class ViewProperties;
 class QLabel;
 class QGraphicsSceneDragDropEvent;
 class QHelpEvent;
+class QProxyStyle;
 class QRegularExpression;
 
 /**
@@ -106,8 +109,14 @@ public:
      * (GeneralSettings::globalViewProps() returns false), then the
      * changed view mode will be stored automatically.
      */
-    void setMode(Mode mode);
-    Mode mode() const;
+    void setViewMode(Mode mode);
+    Mode viewMode() const;
+
+    /**
+     * Enables or disables a mode for quick and easy selection of items.
+     */
+    void setSelectionModeEnabled(bool enabled);
+    bool selectionMode() const;
 
     /**
      * Turns on the file preview for the all files of the current directory,
@@ -282,6 +291,13 @@ public:
      */
     bool itemsExpandable() const;
 
+    /**
+     * @returns true if the @p item is one of the items() of this view and
+     * is currently expanded. false otherwise.
+     * Only directories in view modes that allow expanding can ever be expanded.
+     */
+    bool isExpanded(const KFileItem &item) const;
+
     /**
      * Restores the view state (current item, contents position, details view expansion state)
      */
@@ -599,6 +615,13 @@ Q_SIGNALS:
      */
     void goForwardRequested();
 
+    /**
+     * Used to request either entering or leaving of selection mode
+     * Entering is typically requested on press and hold.
+     * Leaving by pressing Escape when no item is selected.
+     */
+    void selectionModeChangeRequested(bool enabled);
+
     /**
      * Is emitted when the user wants to move the focus to another view.
      */
@@ -916,6 +939,9 @@ private:
     QLabel* m_placeholderLabel;
     QTimer* m_showLoadingPlaceholderTimer;
 
+    /// Used for selection mode. @see setSelectionMode()
+    std::unique_ptr<QProxyStyle> m_proxyStyle;
+
     // For unit tests
     friend class TestBase;
     friend class DolphinDetailsViewTest;
