@@ -10,6 +10,7 @@
 #define DOLPHINVIEWACTIONHANDLER_H
 
 #include "dolphin_export.h"
+#include "selectionmode/bottombar.h"
 #include "views/dolphinview.h"
 
 #include <QObject>
@@ -20,6 +21,9 @@ class QActionGroup;
 class DolphinView;
 class KActionCollection;
 class KFileItemList;
+namespace SelectionMode {
+    class ActionTextHelper;
+}
 
 /**
  * @short Handles all actions for DolphinView
@@ -40,7 +44,7 @@ class DOLPHIN_EXPORT DolphinViewActionHandler : public QObject
     Q_OBJECT
 
 public:
-    explicit DolphinViewActionHandler(KActionCollection* collection, QObject* parent);
+    explicit DolphinViewActionHandler(KActionCollection* collection, SelectionMode::ActionTextHelper* actionTextHelper, QObject* parent);
 
     /**
      * Sets the view that this action handler should work on.
@@ -83,6 +87,9 @@ Q_SIGNALS:
      */
     void createDirectoryTriggered();
 
+    /** Used to request either entering or leaving of selection mode */
+    void selectionModeChangeTriggered(bool enabled, SelectionMode::BottomBar::Contents bottomBarContents = SelectionMode::BottomBar::Contents::GeneralContents);
+
 private Q_SLOTS:
     /**
      * Emitted when the user requested a change of view mode
@@ -234,7 +241,7 @@ private:
      * Create all the actions.
      * This is called only once (by the constructor)
      */
-    void createActions();
+    void createActions(SelectionMode::ActionTextHelper *actionTextHelper);
 
     /**
      * Creates an action-group out of all roles from KFileItemModel.
